\name{ma2D}
\alias{ma2D}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Stratified bivariate robust local regression}
\description{
This function performs robust local regression of a variable \code{z} on predictor variables \code{x} and \code{y}, separately within values of a fourth variable \code{g}. It is used by \code{\link{maNorm2D}} for 2D spatial location normalization.
}
\usage{
ma2D(x, y, z, g, w=NULL, subset=TRUE, span=0.4, ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{A numeric vector of predictor variables.}
  \item{y}{A numeric vector of predictor variables.}
  \item{z}{A numeric vector of responses.}
  \item{g}{Variables used to stratify the data.}
  \item{w}{An optional numeric vector of weights.}
  \item{subset}{A "logical" or "numeric" vector indicating the subset of points used to compute the fits. }
  \item{span}{The argument \code{span} which controls the degree of
    smoothing in the  \code{\link{loess}} function.}
  \item{...}{Misc arguments}
}
\details{
\code{z} is regressed on \code{x} and \code{y}, separately within values of \code{g} using the \code{\link{loess}} function.
}
\value{
A numeric vector of fitted values.
}

\references{S. Dudoit and Y. H. Yang. (2002). Bioconductor R packages for exploratory analysis and normalization of cDNA microarray data. In G. Parmigiani, E. S. Garrett, R. A. Irizarry and S. L. Zeger, editors, \emph{The Analysis of Gene Expression Data: Methods and Software}, Springer, New York.
}

\author{Sandrine Dudoit, \url{http://www.stat.berkeley.edu/~sandrine}.}


\seealso{\code{\link{maNormMain}}, \code{\link{maNorm2D}}, \code{\link{loess}}.}


\examples{
# See examples for maNormMain.
}
\keyword{smooth}% at least one, from doc/KEYWORDS


\eof
\name{maCompNormA}
\alias{maCompNormA}
\alias{maCompNormEq}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Weights for composite normalization}
\description{
This function is used for composite normalization with intensity dependent weights. The function should be used as an argument to the main normalization function \code{\link{maNormMain}}. It only applies when two normalization procedures are combined. 
}
\usage{
maCompNormA()
maCompNormEq()
}
%- maybe also `usage' for other objects documented here.

\value{
  A function which takes as arguments \code{x} and \code{n}, the spot average log-intensities A and the number of normalization procedures. This latter function returns a matrix of weights for combining two normalization procedures, rows correspond to spots and columns to normalization procedures. The weights for the first procedure are given by the empirical cumulative distribution function of the spot average log-intensities A. Note that when performing composite normalization as described in Yang et al. (2002), the first normalization procedure is the global fit and the second procedure is the within-print-tip-group fit.\cr \cr
For \code{maCompEq}, equal weights are given for each procedure.

}

\references{S. Dudoit and Y. H. Yang. (2002). Bioconductor R packages for exploratory analysis and normalization of cDNA microarray data. In G. Parmigiani, E. S. Garrett, R. A. Irizarry and S. L. Zeger, editors, \emph{The Analysis of Gene Expression Data: Methods and Software}, Springer, New York.\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, D. M. Lin, V. Peng, J. Ngai, and T. P. Speed (2002). Normalization for cDNA microarray data: a robust composite method addressing single and multiple slide systematic variation. \emph{Nucleic Acids Research}, Vol. 30, No. 4.
}

\author{Sandrine Dudoit, \url{http://www.stat.berkeley.edu/~sandrine}, Yee Hwa (Jean) Yang.}

\seealso{\code{\link{maNormMain}}, \code{\link{maNormLoess}}, \code{\link{ecdf}}.}

\examples{
# See examples for maNormMain
}
\keyword{smooth}% at least one, from doc/KEYWORDS


\eof
\name{maLoess}
\alias{maLoess}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Stratified univariate robust local regression}
\description{
 This function performs robust local regression of a variable \code{y} on predictor variable \code{x}, separately within values of a third variable \code{z}. It is used by \code{\link{maNormLoess}} for intensity dependent location normalization.
}
\usage{
maLoess(x, y, z, w=NULL, subset=TRUE, span=0.4, ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{A numeric vector of predictor variables.}
  \item{y}{A numeric vector of responses.}
  \item{z}{Variables used to stratify the data.}
  \item{w}{An optional numeric vector of weights.}
  \item{subset}{A "logical" or "numeric" vector indicating the subset of points used to compute the fits. }
  \item{span}{The argument \code{span} which controls the degree of
    smoothing in the  \code{\link{loess}} function.}
    \item{...}{Misc arguments}
}

\details{
\code{y} is regressed on \code{x}, separately within values of \code{z} using the \code{\link{loess}} function.  
}

\value{
A numeric vector of fitted values.
}

\references{S. Dudoit and Y. H. Yang. (2002). Bioconductor R packages for exploratory analysis and normalization of cDNA microarray data. In G. Parmigiani, E. S. Garrett, R. A. Irizarry and S. L. Zeger, editors, \emph{The Analysis of Gene Expression Data: Methods and Software}, Springer, New York.\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, and T. P. Speed (2001). Normalization for cDNA microarray data. In M. L. Bittner, Y. Chen, A. N. Dorsel, and E. R. Dougherty (eds), \emph{Microarrays: Optical Technologies and Informatics}, Vol. 4266 of \emph{Proceedings of SPIE}.\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, D. M. Lin, V. Peng, J. Ngai, and T. P. Speed (2002). Normalization for cDNA microarray data: a robust composite method addressing single and multiple slide systematic variation. \emph{Nucleic Acids Research}, Vol. 30, No. 4.}}

\author{Sandrine Dudoit, \url{http://www.stat.berkeley.edu/~sandrine}.}


\seealso{\code{\link{maNormMain}}, \code{\link{maNormLoess}}, \code{\link{loess}}.}


\examples{
# See examples for maNormMain.

}
\keyword{smooth}% at least one, from doc/KEYWORDS


\eof
\name{maMAD}
\alias{maMAD}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Stratified MAD calculation}
\description{
This function computes the median absolute deviation (MAD) of values in \code{y} separately within values of \code{x}. It is used by \code{\link{maNormMAD}} for MAD scale normalization.
}
\usage{
maMAD(x, y, geo=TRUE, subset=TRUE)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{Variables used to stratify the data.}
  \item{y}{A numeric vector.}
  \item{geo}{If \code{TRUE}, the MAD of each group is divided by the
  geometric mean of the MADs across groups (cf. Yang et al. (2002)). This allows observations to
  retain their original units.}
  \item{subset}{A "logical" or "numeric" vector indicating the subset of points used to compute the MAD. }
}

\value{
A numeric vector of MAD values. 
}


\references{S. Dudoit and Y. H. Yang. (2002). Bioconductor R packages for exploratory analysis and normalization of cDNA microarray data. In G. Parmigiani, E. S. Garrett, R. A. Irizarry and S. L. Zeger, editors, \emph{The Analysis of Gene Expression Data: Methods and Software}, Springer, New York.\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, and T. P. Speed (2001). Normalization for cDNA microarray data. In M. L. Bittner, Y. Chen, A. N. Dorsel, and E. R. Dougherty (eds), \emph{Microarrays: Optical Technologies and Informatics}, Vol. 4266 of \emph{Proceedings of SPIE}.\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, D. M. Lin, V. Peng, J. Ngai, and T. P. Speed (2002). Normalization for cDNA microarray data: a robust composite method addressing single and multiple slide systematic variation. \emph{Nucleic Acids Research}, Vol. 30, No. 4.
}

\author{Sandrine Dudoit, \url{http://www.stat.berkeley.edu/~sandrine}.}


\seealso{\code{\link{maNormMain}}, \code{\link{maNormMAD}}, \code{\link{mad}}.}

\examples{
# See examples for maNormMain.

}

\keyword{univar}% at least one, from doc/KEYWORDS
\keyword{robust}% __ONLY ONE__ keyword per line

\eof
\name{maMed}
\alias{maMed}
\title{Stratified median calculation}
\description{
This function computes the median of values in \code{y} separately within values of \code{x}. It is used by \code{\link{maNormMed}} for median location normalization.
}
\usage{
maMed(x, y, subset=TRUE)
}
\arguments{
  \item{x}{Variables used to stratify the data.}
  \item{y}{A numeric vector.}
  \item{subset}{A "logical" or "numeric" vector indicating the subset of points used to compute the median. }
}

\value{
A numeric vector of median values. 
}


\references{S. Dudoit and Y. H. Yang. (2002). Bioconductor R packages for exploratory analysis and normalization of cDNA microarray data. In G. Parmigiani, E. S. Garrett, R. A. Irizarry and S. L. Zeger, editors, \emph{The Analysis of Gene Expression Data: Methods and Software}, Springer, New York.\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, and T. P. Speed (2001). Normalization for cDNA microarray data. In M. L. Bittner, Y. Chen, A. N. Dorsel, and E. R. Dougherty (eds), \emph{Microarrays: Optical Technologies and Informatics}, Vol. 4266 of \emph{Proceedings of SPIE}.\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, D. M. Lin, V. Peng, J. Ngai, and T. P. Speed (2002). Normalization for cDNA microarray data: a robust composite method addressing single and multiple slide systematic variation. \emph{Nucleic Acids Research}, Vol. 30, No. 4.
}

\author{Sandrine Dudoit, \url{http://www.stat.berkeley.edu/~sandrine}.}


\seealso{\code{\link{maNormMain}}, \code{\link{maNormMed}}, \code{\link{median}}.}


\examples{
# See examples for maNormMain.

}

\keyword{univar}
\keyword{robust}

\eof
\name{maNorm}
\alias{maNorm}
\title{Simple location and scale normalization function}
\description{
This function is a simple wrapper function around the main normalization function \code{\link{maNormMain}}. It allows the user to choose from a set of six basic location and scale normalization procedures. The function operates on an object of class \code{"\link{marrayRaw}"} (or possibly \code{"\link{marrayNorm}"}, if normalization is performed in several steps) and returns an object of class \code{"\link{marrayNorm}"}.
}
\usage{
maNorm(mbatch, norm=c("printTipLoess", "none", "median", "loess",
"twoD", "scalePrintTipMAD"), subset=TRUE, span=0.4, Mloc=TRUE,
Mscale=TRUE, echo=FALSE, ...)
}
\arguments{
  \item{mbatch}{Object of class \code{\link{marrayRaw}}, containing intensity 
data for the batch of arrays to be normalized. 
An object of class \code{"\link{marrayNorm}"} may also be passed if 
normalization is performed in several steps.}
\item{norm}{Character string specifying the normalization procedures: 
\describe{
\item{none}{no normalization}
\item{median}{for global median location normalization}
\item{loess}{for global intensity or A-dependent location normalization using 
the \code{\link{loess}} function}
\item{twoD}{for 2D spatial location normalization using the 
\code{\link{loess}} function}
\item{printTipLoess}{for within-print-tip-group intensity dependent location 
normalization using the \code{\link{loess}} function}
\item{scalePrintTipMAD}{for within-print-tip-group intensity dependent 
location normalization followed by within-print-tip-group scale normalization 
using the median absolute deviation (MAD). \cr
}
This argument can be specified using the first letter of each method.}}
  \item{subset}{A "logical" or "numeric" vector indicating the subset of points used to
  compute the  normalization values.}
 \item{span}{The argument \code{span} which controls the degree of smoothing in the \code{\link{loess}} function.}
\item{Mloc}{If \code{TRUE}, the location normalization values are stored in the slot \code{maMloc} of the object of class \code{"\link{marrayNorm}"} returned by the function, if \code{FALSE}, these values are not retained.}
  \item{Mscale}{If \code{TRUE}, the scale normalization values are stored in the slot \code{maMscale} of the object of class \code{"\link{marrayNorm}"} returned by the function, if \code{FALSE}, these values are not retained.}
\item{echo}{If \code{TRUE}, the index of the array currently being
  normalized is printed.}
\item{...}{Misc arguments}
}
\details{
See \code{\link{maNormMain}} for details and also more general procedures.
}
\value{
 \item{mnorm}{An object of class \code{"\link{marrayNorm}"}, containing the normalized intensity data.}
}


\references{S. Dudoit and Y. H. Yang. (2002). Bioconductor R packages for exploratory analysis and normalization of cDNA microarray data. In G. Parmigiani, E. S. Garrett, R. A. Irizarry and S. L. Zeger, editors, \emph{The Analysis of Gene Expression Data: Methods and Software}, Springer, New York.\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, and T. P. Speed (2001). Normalization for cDNA microarray data. In M. L. Bittner, Y. Chen, A. N. Dorsel, and E. R. Dougherty (eds), \emph{Microarrays: Optical Technologies and Informatics}, Vol. 4266 of \emph{Proceedings of SPIE}.\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, D. M. Lin, V. Peng, J. Ngai, and T. P. Speed (2002). Normalization for cDNA microarray data: a robust composite method addressing single and multiple slide systematic variation. \emph{Nucleic Acids Research}, Vol. 30, No. 4.
}

\author{Sandrine Dudoit, \url{http://www.stat.berkeley.edu/~sandrine}.}

\seealso{\code{\link{maNormMain}}, \code{\link{maNormScale}}.}

\examples{
# Examples use swirl dataset, for description type ? swirl
data(swirl)

# Global median normalization for swirl arrays 2 and 3
mnorm<-maNorm(swirl[,2:3], norm="median", echo=TRUE)

# Within-print-tip-group loess location normalization for swirl array 1
mnorm<-maNorm(swirl[,1], norm="p", span=0.45)

}




\keyword{smooth}% at least one, from doc/KEYWORDS
\keyword{methods}% __ONLY ONE__ keyword per line

\eof
\name{maNorm2D}
\alias{maNorm2D}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{2D spatial location normalization function}
\description{
This function is used for 2D spatial location normalization, using the robust local regression function \code{\link{loess}}.  It should be used as an argument to the main normalization function \code{\link{maNormMain}}.
}

\usage{
maNorm2D(x="maSpotRow", y="maSpotCol", z="maM", g="maPrintTip", w=NULL,
subset=TRUE, span=0.4, ...)
}
%- maybe also `usage' for other objects documented here.
\arguments{
  \item{x}{Name of accessor method for spot row coordinates, usually \code{maSpotRow}.}
  \item{y}{Name of accessor method for spot column coordinates, usually \code{maSpotCol}.}
  \item{z}{Name of accessor method for spot statistics, usually the log-ratio \code{maM}.}
  \item{g}{Name of accessor method for print-tip-group indices, usually \code{maPrintTip}.}
  \item{w}{An optional numeric vector of weights.}
  \item{subset}{A "logical" or "numeric" vector indicating the subset of points used to
  compute the fits. }
\item{span}{The argument \code{span} which controls the degree of
  smoothing in the  \code{\link{loess}} function.}
  \item{...}{Misc arguments}
}

\details{
The spot statistic named in \code{z} is regressed on spot row and column coordinates, separately within print-tip-group, using the \code{\link{loess}} function.
}

\value{
 A function with bindings for the above arguments. This latter function takes as argument an object of class \code{"\link{marrayRaw}"} (or possibly \code{"\link{marrayNorm}"}), and returns a vector of fitted values to be substracted from the raw log-ratios. It calls the function \code{\link{ma2D}}, which is not specific to microarray objects.
}

\references{S. Dudoit and Y. H. Yang. (2002). Bioconductor R packages for exploratory analysis and normalization of cDNA microarray data. In G. Parmigiani, E. S. Garrett, R. A. Irizarry and S. L. Zeger, editors, \emph{The Analysis of Gene Expression Data: Methods and Software}, Springer, New York.
}

\author{Sandrine Dudoit, \url{http://www.stat.berkeley.edu/~sandrine}.}


\seealso{\code{\link{maNormMain}}, \code{\link{ma2D}}, \code{\link{loess}}.}

\examples{
# See examples for maNormMain.

}
\keyword{smooth}% at least one, from doc/KEYWORDS


\eof
\name{maNormLoess}
\alias{maNormLoess}
\title{Intensity dependent location normalization function}
\description{
This function is used for intensity dependent location normalization, using the robust local regression function \code{\link{loess}}.  It should be used as an argument to the main normalization function \code{\link{maNormMain}}.
}
\usage{
maNormLoess(x="maA", y="maM", z="maPrintTip", w=NULL, subset=TRUE,
span=0.4, ...)
}
\arguments{
  \item{x}{Name of accessor method for spot statistics, usually \code{maA}.}
  \item{y}{Name of accessor method for spot statistics, usually \code{maM}.}
  \item{z}{Name of accessor method for spot statistic used to stratify the data, usually a layout parameter, e.g. \code{maPrintTip} or \code{maPlate}. If \code{z} is not a character, e.g. NULL,  the data are not stratified.}
  \item{w}{An optional numeric vector of weights.}
  \item{subset}{A "logical" or "numeric" vector indicating the subset of points used to compute the fits.}
  \item{span}{The argument \code{span} which controls the degree of
    smoothing in the  \code{\link{loess}} function.}
  \item{...}{Misc arguments}
}

\value{
 A function with bindings for the above arguments. This latter function takes as argument an object of class \code{"\link{marrayRaw}"}  (or possibly \code{"\link{marrayNorm}"}), and returns a vector of fitted values to be substracted from the raw log-ratios. It calls the function \code{\link{maLoess}}, which is not specific to microarray objects.
}

\references{
S. Dudoit and Y. H. Yang. (2002). Bioconductor R packages for exploratory analysis and normalization of cDNA microarray data. In G. Parmigiani, E. S. Garrett, R. A. Irizarry and S. L. Zeger, editors, \emph{The Analysis of Gene Expression Data: Methods and Software}, Springer, New York.\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, and T. P. Speed (2001). Normalization for cDNA microarray data. In M. L. Bittner, Y. Chen, A. N. Dorsel, and E. R. Dougherty (eds), \emph{Microarrays: Optical Technologies and Informatics}, Vol. 4266 of \emph{Proceedings of SPIE}.
\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, D. M. Lin, V. Peng, J. Ngai, and T. P. Speed (2002). Normalization for cDNA microarray data: a robust composite method addressing single and multiple slide systematic variation. \emph{Nucleic Acids Research}, Vol. 30, No. 4.
}

\author{Sandrine Dudoit, \url{http://www.stat.berkeley.edu/~sandrine}.}


\seealso{\code{\link{maNormMain}}, \code{\link{maLoess}}, \code{\link{loess}}.}

\examples{
# See examples for maNormMain.

}

\keyword{smooth}


\eof
\name{maNormMAD}
\alias{maNormMAD}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{MAD scale normalization function}
\description{
This function is used for scale normalization using the median absolute deviation (MAD) of intensity log-ratios for a group of spots. It can be used for within or between array normalization. The function should be used as an argument to the main normalization function \code{\link{maNormMain}}.
}

\usage{
maNormMAD(x=NULL, y="maM", geo=TRUE, subset=TRUE)
}
%- maybe also `usage' for other objects documented here.

\arguments{
  \item{x}{Name of accessor function for spot statistic used to stratify the data, usually a layout parameter, e.g. \code{maPrintTip} or \code{maPlate}. If \code{x} is not a character, e.g. NULL, the data are not stratified.}
  \item{y}{Name of accessor function for spot statistics, usually
  \code{maM}.}
  \item{geo}{If \code{TRUE}, the MAD of each group is divided by the
  geometric mean of the MADs across groups (cf. Yang et al. (2002)). This allows observations to
  retain their original units.}
  \item{subset}{A "logical" or "numeric" vector indicating the subset of points used to compute the scale normalization values. }
}

\value{
A function with bindings for the above arguments. This latter function takes as argument an object of class \code{"\link{marrayRaw}"}  (or possibly \code{"\link{marrayNorm}"}), and returns a vector of values used to scale the location normalized log-ratios. It calls the function \code{\link{maMAD}}, which is not specific to microarray objects.
}


\references{S. Dudoit and Y. H. Yang. (2002). Bioconductor R packages for exploratory analysis and normalization of cDNA microarray data. In G. Parmigiani, E. S. Garrett, R. A. Irizarry and S. L. Zeger, editors, \emph{The Analysis of Gene Expression Data: Methods and Software}, Springer, New York.\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, and T. P. Speed (2001). Normalization for cDNA microarray data. In M. L. Bittner, Y. Chen, A. N. Dorsel, and E. R. Dougherty (eds), \emph{Microarrays: Optical Technologies and Informatics}, Vol. 4266 of \emph{Proceedings of SPIE}.
\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, D. M. Lin, V. Peng, J. Ngai, and T. P. Speed (2002). Normalization for cDNA microarray data: a robust composite method addressing single and multiple slide systematic variation. \emph{Nucleic Acids Research}, Vol. 30, No. 4.
}

\author{Sandrine Dudoit, \url{http://www.stat.berkeley.edu/~sandrine}.}


\seealso{\code{\link{maNormMain}}, \code{\link{maMAD}}, \code{\link{mad}}.}

\examples{
# See examples for maNormMain.

}

\keyword{univar}% at least one, from doc/KEYWORDS
\keyword{robust}% __ONLY ONE__ keyword per line

\eof
\name{maNormMain}
\alias{maNormMain}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Main function for location and scale normalization of cDNA microarray data}
\description{
This is the main function for location and scale normalization of cDNA microarray data. Normalization is performed for a batch of arrays using location and scale normalization procedures specified by the lists of functions \code{f.loc} and \code{f.scale}. Typically, only one function is given in each list, otherwise composite normalization is performed using the weights computed by the functions \code{a.loc} and \code{a.scale}. The function operates on an object of class \code{"\link{marrayRaw}"} (or possibly \code{"\link{marrayNorm}"}, if normalization is performed in several steps) and returns an object of class \code{"\link{marrayNorm}"}. Simple wrapper functions are provided by \code{\link{maNorm}} and \code{\link{maNormScale}}.
}

\usage{
maNormMain(mbatch, f.loc=list(maNormLoess()), f.scale=NULL,
a.loc=maCompNormEq(), a.scale=maCompNormEq(), Mloc=TRUE, Mscale=TRUE, echo=FALSE)
}
%- maybe also `usage' for other objects documented here.

\arguments{
  \item{mbatch}{An object of class \code{"\link{marrayRaw}"}, containing intensity data for the batch of arrays to be normalized. An object of class \code{"\link{marrayNorm}"} may also be passed if normalization is performed in several steps.}
  \item{f.loc}{A list of location normalization functions, e.g., \code{\link{maNormLoess}}, \code{\link{maNormMed}}, or \code{\link{maNorm2D}}.}
  \item{f.scale}{A list of scale normalization functions, .e.g, \code{\link{maNormMAD}}.}
  \item{a.loc}{For composite normalization, a function for computing the weights used in combining several location normalization functions, e.g., \code{\link{maCompNormA}}.}
  \item{a.scale}{For composite normalization, a function for computing
  the weights used in combining several scale normalization functions.}
  \item{Mloc}{If \code{TRUE}, the location normalization values are stored in the slot \code{maMloc} of the object of class \code{"\link{marrayNorm}"} returned by the function, if \code{FALSE}, these values are not retained.}
  \item{Mscale}{If \code{TRUE}, the scale normalization values are stored in the slot \code{maMscale} of the object of class \code{"\link{marrayNorm}"} returned by the function, if \code{FALSE}, these values are not retained.}
  \item{echo}{If \code{TRUE}, the index of the array currently being
  normalized is printed.}
}

\details{
When both location and scale normalization functions (\code{f.loc} and \code{f.scale}) are passed, location normalization is performed before scale normalization. That is, scale values are computed for the location normalized log-rations. The same results could be obtained by two applications of the function \code{maNormMain}, first with only the location normalization function and \code{f.scale=NULL}, and second with only the scale normalization function and \code{f.loc=NULL}.
}

\value{
  \item{mnorm}{An object of class \code{"\link{marrayNorm}"}, containing the normalized intensity data.}
}

\references{S. Dudoit and Y. H. Yang. (2002). Bioconductor R packages for exploratory analysis and normalization of cDNA microarray data. In G. Parmigiani, E. S. Garrett, R. A. Irizarry and S. L. Zeger, editors, \emph{The Analysis of Gene Expression Data: Methods and Software}, Springer, New York.\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, and T. P. Speed (2001). Normalization for cDNA microarray data. In M. L. Bittner, Y. Chen, A. N. Dorsel, and E. R. Dougherty (eds), \emph{Microarrays: Optical Technologies and Informatics}, Vol. 4266 of \emph{Proceedings of SPIE}.\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, D. M. Lin, V. Peng, J. Ngai, and T. P. Speed (2002). Normalization for cDNA microarray data: a robust composite method addressing single and multiple slide systematic variation. \emph{Nucleic Acids Research}, Vol. 30, No. 4.
}

\author{Sandrine Dudoit, \url{http://www.stat.berkeley.edu/~sandrine}.}


\seealso{\code{\link{maNorm}}, \code{\link{maNormScale}}, \code{\link{maNormLoess}}, \code{\link{maLoess}},
\code{\link{maNormMAD}}, \code{\link{maMAD}},
\code{\link{maNormMed}}, \code{\link{maMed}},
\code{\link{maNorm2D}}, \code{\link{ma2D}},
\code{\link{maCompNormA}}, \code{\link{maCompNormEq}}.}

\examples{
# Examples use swirl dataset, for description type ? swirl
data(swirl)

# Within-print-tip-group loess location normalization of batch swirl
# - Default normalization
swirl.norm<-maNormMain(swirl)

## Only do the plotting if we have marrayPlots.  Record if
## we have it or not in 'haveMP' boolean variable
haveMP <- FALSE
if (require("marrayPlots", quietly=TRUE)) {
   haveMP <- TRUE
   maBoxplot(swirl.norm)
   maBoxplot(swirl.norm[,3])
   maPlot(swirl.norm[,3])
   maImage(swirl.norm, x="maMloc")
   maImage(swirl.norm, x="maM")
} 

# 2D spatial location normalization of array 93
swirl.norm <- maNormMain(swirl[,3], f.loc = list(maNorm2D()))

if (haveMP) {
  maImage(swirl, x="maM")
  maImage(swirl.norm, x="maMloc")
  maImage(swirl.norm, x="maM")
}


# Global median normalization for arrays 81 and 82
swirl.norm <- maNormMain(swirl[,1:2], f.loc = list(maNormMed(x=NULL,y="maM")))

# Global loess normalization for array 81
swirl.norm <- maNormMain(swirl[,1], f.loc = list(maNormLoess(x="maA",y="maM",z=NULL)))

# Composite normalization as in Yang et al. (2002)
# No MSP controls are available here, so all spots are used for illustration
# purposes
swirl.norm <- maNormMain(swirl[,1], f.loc = list(maNormLoess(x="maA",y="maM",z=NULL),maNormLoess(x="maA",y="maM",z="maPrintTip")), a.loc=maCompNormA())


}
\keyword{smooth}% at least one, from doc/KEYWORDS
\keyword{methods}% __ONLY ONE__ keyword per line

\eof
\name{maNormMed}
\alias{maNormMed}
\title{Median location normalization function}

\description{
This function is used for location normalization using the median of 
intensity log-ratios for a group of spots. The function should be used 
as an argument to the main normalization function \code{\link{maNormMain}}.
}

\usage{
maNormMed(x=NULL, y="maM", subset=TRUE)
}

\arguments{
  \item{x}{Name of accessor method for spot statistic used to stratify the 
data, usually a layout parameter, e.g. \code{maPrintTip} or \code{maPlate}. 
If \code{x} is not a character, e.g. NULL, the data are not stratified.}
  \item{y}{Name of accessor method for spot statistics, usually \code{maM}.}
  \item{subset}{A "logical" or "numeric" vector indicating the subset of points   used to compute the location normalization values. }
}


\value{
A function with bindings for the above arguments. This latter function takes as 
argument an object of class \code{"\link{marrayRaw}"} (or possibly 
\code{"\link{marrayNorm}"}), and returns a vector of fitted values to be 
subtracted from the raw log-ratios. It calls the function \code{\link{maMed}}, 
which is not specific to microarray objects.
}

\references{S. Dudoit and Y. H. Yang. (2002). Bioconductor R packages for 
exploratory analysis and normalization of cDNA microarray data. 
In G. Parmigiani, E. S. Garrett, R. A. Irizarry and S. L. Zeger, editors, 
\emph{The Analysis of Gene Expression Data: Methods and Software}, Springer, 
New York.\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, and T. P. Speed (2001). Normalization for cDNA 
microarray data. In M. L. Bittner, Y. Chen, A. N. Dorsel, and E. R. Dougherty 
(eds), \emph{Microarrays: Optical Technologies and Informatics}, 
Vol. 4266 of \emph{Proceedings of SPIE}.\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, D. M. Lin, V. Peng, J. Ngai, and T. P. Speed 
(2002). Normalization for cDNA microarray data: a robust composite method 
addressing single and multiple slide systematic variation. 
\emph{Nucleic Acids Research}, Vol. 30, No. 4.
}

\author{Sandrine Dudoit, \url{http://www.stat.berkeley.edu/~sandrine}.}


\seealso{\code{\link{maNormMain}}, \code{\link{maMed}}, \code{\link{median}}.}

\examples{
# See examples for maNormMain.

}
\keyword{univar}
\keyword{robust}

\eof
\name{maNormScale}
\alias{maNormScale}
\title{Simple scale normalization function}
\description{
This function is a simple wrapper function around the main normalization
function \code{\link{maNormMain}}. It allows the user to choose from a
set of two basic scale normalization procedures. The function operates
on an object of class \code{"\link{marrayRaw}"} (or possibly
\code{"\link{marrayNorm}"}, if normalization is performed in several
steps) and returns an object of class \code{"\link{marrayNorm}"}. This
function can be used to conormalize a batch of arrays 
(\code{norm="globalMAD"} option).
}
\usage{
maNormScale(mbatch, norm=c("globalMAD", "printTipMAD"), subset=TRUE, geo=TRUE,  Mscale=TRUE, echo=FALSE)
}

\arguments{
  \item{mbatch}{An object of class \code{"\link{marrayRaw}"}, containing 
intensity data for the batch of arrays to be normalized. An object of class 
\code{\link{marrayNorm}} may also be passed if normalization is performed 
in several steps.}
\item{norm}{A character string specifying the normalization
  procedures: 
\describe{
\item{globalMAD}{for global scale
  normalization using the median absolute deviation (MAD), this allows between 
slide scale normalization}
\item{printTipMAD}{for within-print-tip-group scale normalization
  using the median absolute deviation (MAD).}
This argument can be
  specified using the first letter of each method.}}
  \item{subset}{A "logical" or "numeric" vector indicating the subset of points used to
  compute the  normalization values.}
 \item{geo}{If \code{TRUE}, the MAD of each group is divided by the
  geometric mean of the MADs across groups (cf. Yang et al. (2002)). This allows observations to
  retain their original units.}
  \item{Mscale}{If \code{TRUE}, the scale normalization values are stored in the slot \code{maMscale} of the object of class \code{"\link{marrayNorm}"} returned by the function, if \code{FALSE}, these values are not retained.}
\item{echo}{If \code{TRUE}, the index of the array currently being
  normalized is printed.}
}
\details{
See \code{\link{maNormMain}} for details and more general procedures.
}
\value{
\item{mnorm}{An object of class \code{"\link{marrayNorm}"}, containing the normalized intensity data.}
}

\references{S. Dudoit and Y. H. Yang. (2002). Bioconductor R packages for exploratory analysis and normalization of cDNA microarray data. In G. Parmigiani, E. S. Garrett, R. A. Irizarry and S. L. Zeger, editors, \emph{The Analysis of Gene Expression Data: Methods and Software}, Springer, New York.\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, and T. P. Speed (2001). Normalization for cDNA microarray data. In M. L. Bittner, Y. Chen, A. N. Dorsel, and E. R. Dougherty (eds), \emph{Microarrays: Optical Technologies and Informatics}, Vol. 4266 of \emph{Proceedings of SPIE}.\cr \cr

Y. H. Yang, S. Dudoit, P. Luu, D. M. Lin, V. Peng, J. Ngai, and T. P. Speed (2002). Normalization for cDNA microarray data: a robust composite method addressing single and multiple slide systematic variation. \emph{Nucleic Acids Research}, Vol. 30, No. 4.
}

\author{Sandrine Dudoit, \url{http://www.stat.berkeley.edu/~sandrine}.}

\seealso{\code{\link{maNormMain}}, \code{\link{maNorm}}.}


\examples{
# Examples use swirl dataset, for description type ? swirl
data(swirl)

# Global median normalization followed by global MAD normalization for 
# only arrays 2 and 3 in the batch swirl

mnorm1<-maNorm(swirl[,2:3], norm="m")
mnorm2<-maNormScale(mnorm1, norm="g")

}

\keyword{smooth}% at least one, from doc/KEYWORDS
\keyword{methods}% __ONLY ONE__ keyword per line

\eof
